QueryCommand<G extends FlameGame<World>> class abstract

Inheritance
Implementers

Constructors

QueryCommand()

Properties

description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
parser → ArgParser
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(G game, ArgResults results) → (String?, String)
listAllChildren(Component component) List<Component>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChildMatch(void onChild(Component), {required Component rootComponent, List<String> ids = const [], List<String> types = const [], int? limit}) → void
inherited
optionalIntResult(String key, ArgResults results) int?
inherited
processChildren(List<Component> children) → (String?, String)
run(G subject, List<String> args) → (String?, String)
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited