FlameConsoleView<G extends FlameGame<World> > class
A Console like view that can be used to interact with a game.
It should be registered as an overlay in the game widget of the game you want to interact with.
Example:
GameWidget(
game: _game,
overlayBuilderMap: {
'console': (BuildContext context, MyGame game) => ConsoleView(
game: game,
onClose: () {
_game.overlays.remove('console');
},
),
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlameConsoleView
Constructors
-
FlameConsoleView({required G game, required VoidCallback onClose, List<
FlameConsoleCommand< ? customCommands, TerminuiRepository? repository, ContainerBuilder? containerBuilder, WidgetBuilder? cursorBuilder, Color? cursorColor, HistoryBuilder? historyBuilder, TextStyle? textStyle, Key? key})G> > -
const
Properties
- containerBuilder → ContainerBuilder?
-
final
- cursorBuilder → WidgetBuilder?
-
final
- cursorColor → Color?
-
final
-
customCommands
→ List<
FlameConsoleCommand< ?G> > -
final
- game → G
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyBuilder → HistoryBuilder?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → VoidCallback
-
final
- repository → TerminuiRepository?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlameConsoleView< FlameGame< >World> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited